@@ -9,7 +9,7 @@ use POE::Component::AI::MegaHAL;
 use POE::Component::IRC::Common qw(l_irc matches_mask_array irc_to_utf8 strip_color strip_formatting);
 use POE::Component::IRC::Plugin qw(PCI_EAT_NONE);
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 sub new {
     my ($package, %args) = @_;
@@ -147,7 +147,7 @@ sub _greet_handler {
     return;
 }
 
-sub normalize_megahal {
+sub _normalize_megahal {
     my ($self, $line) = @_;
 
     $line = decode('utf8', $line);
